@@ -1,12 +1,12 @@
 package Dist::Build::Core;
-$Dist::Build::Core::VERSION = '0.014';
+$Dist::Build::Core::VERSION = '0.015';
 use strict;
 use warnings;
 
 use parent 'ExtUtils::Builder::Planner::Extension';
 
 use Exporter 5.57 'import';
-our @EXPORT_OK = qw/copy make_executable manify tap_harness install/;
+our @EXPORT_OK = qw/copy make_executable manify tap_harness install dump_binary dump_text dump_json/;
 
 use Carp qw/croak/;
 use ExtUtils::Helpers 0.028 qw/make_executable man1_pagename man3_pagename/;
@@ -49,7 +49,7 @@ sub add_methods {
 	my ($self, $planner) = @_;
 
 	$planner->add_delegate('copy_file', sub {
-		my (undef, $source, $destination) = @_;
+		my ($planner, $source, $destination) = @_;
 		my $copy = new_action('copy', $source, $destination);
 		$planner->create_node(
 			target       => $destination,
@@ -59,7 +59,7 @@ sub add_methods {
 	});
 
 	$planner->add_delegate('copy_executable', sub {
-		my (undef, $source, $destination) = @_;
+		my ($planner, $source, $destination) = @_;
 		my $copy = new_action('copy', $source, $destination);
 		my $make_executable = new_action('make_executable', $destination);
 		$planner->create_node(
@@ -70,7 +70,7 @@ sub add_methods {
 	});
 
 	$planner->add_delegate('manify', sub {
-		my (undef, $source, $destination, $section) = @_;
+		my ($planner, $source, $destination, $section) = @_;
 		my $manify = new_action('manify', $source, $destination, $section);
 		my $dirname = dirname($destination);
 		$planner->create_node(
@@ -81,7 +81,7 @@ sub add_methods {
 	});
 
 	$planner->add_delegate('mkdir', sub {
-		my (undef, $target, %options) = @_;
+		my ($planner, $target, %options) = @_;
 		my $action = ExtUtils::Builder::Action::Function->new(
 			function  => 'make_path',
 			module    => 'File::Path',
@@ -96,7 +96,7 @@ sub add_methods {
 	});
 
 	$planner->add_delegate('tap_harness', sub {
-		my (undef, $target, %options) = @_;
+		my ($planner, $target, %options) = @_;
 		$planner->create_node(
 			target       => $target,
 			dependencies => $options{dependencies},
@@ -108,7 +108,7 @@ sub add_methods {
 	});
 
 	$planner->add_delegate('install', sub {
-		my (undef, $target, %options) = @_;
+		my ($planner, $target, %options) = @_;
 		$planner->create_node(
 			target       => $target,
 			dependencies => $options{dependencies},
@@ -120,34 +120,34 @@ sub add_methods {
 	});
 
 	$planner->add_delegate('dump_binary', sub {
-		my (undef, $target, %options) = @_;
+		my ($planner, $target, $content, %options) = @_;
 		$planner->create_node(
 			target       => $target,
 			dependencies => $options{dependencies},
 			actions      => [
-				new_action('dump_binary', $options{content}),
+				new_action('dump_binary', $target, $content),
 			]
 		);
 	});
 
 	$planner->add_delegate('dump_text', sub {
-		my (undef, $target, %options) = @_;
+		my ($planner, $target, $content, %options) = @_;
 		$planner->create_node(
 			target       => $target,
 			dependencies => $options{dependencies},
 			actions      => [
-				new_action('dump_text', $options{content}, $options{encoding} || 'utf-8'),
+				new_action('dump_text', $target, $content, $options{encoding} // 'utf-8'),
 			]
 		);
 	});
 
 	$planner->add_delegate('dump_json', sub {
-		my (undef, $target, %options) = @_;
+		my ($planner, $target, $content, %options) = @_;
 		$planner->create_node(
 			target       => $target,
 			dependencies => $options{dependencies},
 			actions      => [
-				new_action('dump_json', $options{content}),
+				new_action('dump_json', $target, $content),
 			]
 		);
 	});
@@ -338,7 +338,7 @@ Dist::Build::Core - core functions for Dist::Build
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 DESCRIPTION
 
@@ -404,15 +404,15 @@ This uninstalls files before installing the new ones.
 
 =back
 
-=item * dump_binary($filename, $content)
+=item * dump_binary($filename, $content, %named_arguments)
 
 Write C<$content> to C<$filename> as binary data.
 
-=item * dump_text($filename, $content, $encoding = 'utf8')
+=item * dump_text($filename, $content, %named_arguments)
 
 Write C<$content> to C<$filename> as text of the given encoding.
 
-=item * dump_json($filename, $content)
+=item * dump_json($filename, $content, %named_arguments)
 
 Write C<$content> to C<$filename> as JSON.
 
