@@ -1,13 +1,17 @@
 package Dist::Build::XS::Import;
-$Dist::Build::XS::Import::VERSION = '0.014';
+$Dist::Build::XS::Import::VERSION = '0.015';
 use strict;
 use warnings;
 
 use parent 'ExtUtils::Builder::Planner::Extension';
 
 use Carp 'croak';
-use File::Spec::Functions 'catdir';
+use File::Spec::Functions qw/catfile catdir/;
 use File::ShareDir::Tiny 'module_dir';
+use Parse::CPAN::Meta;
+
+my $json_backend = Parse::CPAN::Meta->json_backend;
+my $json = $json_backend->new->canonical->pretty->utf8;
 
 sub add_methods {
 	my ($self, $planner, %args) = @_;
@@ -21,10 +25,27 @@ sub add_methods {
 			my @modules = ref $import ? @{ $import } : $import;
 			for my $module (@modules) {
 				my $module_dir = module_dir($module);
+				my $config = catfile($module_dir, 'compile.json');
 				my $include = catdir($module_dir, 'include');
-				croak "No such import $module" if not -d $include;
+				croak "No such import $module" if not -d $include and not -e $config;
 
-				unshift @{ $args{include_dirs} }, $include;
+				if (-d $include) {
+					unshift @{ $args{include_dirs} }, $include;
+				}
+
+				if (-e $config) {
+					open my $fh, '<:raw', $config or die "Could not open $config: $!";
+					my $content = do { local $/; <$fh> };
+					my $payload = $json->decode($content);
+
+					for my $key (qw/include_dirs library_dirs libraries extra_compiler_flags extra_linker_flags/) {
+						unshift @{ $args{$key} }, @{ $payload->{$key} || [] };
+					}
+
+					for my $key (%{ $payload->{defines} || {} }) {
+						$args{defines}{$key} //= $payload->{defines}{$key};
+					}
+				}
 			}
 		}
 
@@ -48,7 +69,7 @@ Dist::Build::XS::Import - Dist::Build extension to import headers for other XS m
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -62,7 +83,7 @@ version 0.014
 
 =head1 DESCRIPTION
 
-This module is an extension of L<Dist::Build::XS|Dist::Build::XS>, adding an additional argument to the C<add_xs> function: C<import>. It will add the include dir (as exported by L<Dist::Build::XS::Export|Dist::Build::XS::Export>)
+This module is an extension of L<Dist::Build::XS|Dist::Build::XS>, adding an additional argument to the C<add_xs> function: C<import>. It is a counterpart to L<Dist::Build::XS::Export|Dist::Build::XS::Export>) will add the include dir and compilation flags for the given module.
 
 =head1 AUTHOR
 
